pro mmcorr, mm_rx, mm_tel_iau, parallactic_deg, stk_meas, stk_corr, $
	m_rho_x= m_rho_x, m_tel_iau=m_tel_iau
;+
;PURPOSE: Mueller-correct the stk_meas array to its corrected version
;       by applying mm_rx and, if selected, mm_rho_x and/or
;       mm_tel_iau.
;
;CALLING SEQUENCE:
; MMCORR, mm_rx, mm_tel_iau, parallactic_deg, stk_meas, stk_corr
;	m_rho_x= m_rho_x, m_tel_iau=m_tel_iau
;
;INPUTS:
;MM_RX[ 4,4], the Mueller Matrix M_{rx} in the RHSTK doc
;MM_TEL_IAU[ 4,4], the Mueller Matrix M_{tel-IAU} in the RHSTK doc. NO
;       NEED TO SPECIFY IT IF M_TEL_IAU IS NOT SET.
;PARALLACTIC_DEG[ nrpos], the vector of parallactic angle in degrees
;STK_MEAS[ nrchnls, 4, nrpos]: the array of stokes parameters to be
;       corrected. nrchnls: the numbere of spectral channels. nr
;
;KEYWORDS:
; M_RHO_X, setting it includes MM_RHO_X correction; default is zero.
; M_TEL_IAU, setting it includes MM_TEL_IAU correction; default is zero.
;  (which defines the sense of circular and applies the proper
;  position angle to obtain true sky stokes parameters)
;  default is zero.
;
;OUTPUTS:
; STK_CORR: the corrected STK_MEAS ARRAY
;-

sz= size( stk_meas)
stk_corr= fltarr( sz[1], sz[2], sz[3])
nrpos= sz[ 3]
parallactic= reform( !dtor* parallactic_deg, nrpos)

mm_total= fltarr( 4,4, nrpos)

;CALCULATE MM_RHO_X...IF DESIRED...
IF KEYWORD_SET( M_RHO_X) THEN BEGIN
   mm_rho_x= fltarr( 4,4, nrpos)
   mm_rho_x[ 0,0, *]= 1.
   mm_rho_x[ 3,3, *]= 1.
   mm_rho_x[ 1,1, *]= cos( 2.* parallactic)
   mm_rho_x[ 2,1, *]= sin( 2.* parallactic)
   mm_rho_x[ 2,2, *]= mm_rho_x[ 1,1, *]
   mm_rho_x[ 1,2, *]= -mm_rho_x[ 2,1, *]
   for nr=0, nrpos-1 do mm_total[ *,*,nr]= mm_rx ## mm_rho_x[ *,*,nr]
ENDIF ELSE for nr=0, nrpos-1 do mm_total[ *,*,nr]= mm_rx
      
;DON'T FORGET TO TAKE THE INVERSE!!!
for nr=0, nrpos-1 do mm_total[ *,*,nr]= invert( mm_total[ *,*,nr])

;THEN ROTATE TO ASTRONOMICAL PS IF DESIRED...
if keyword_set( m_tel_iau) then $
for nr=0, nrpos-1 do mm_total[ *,*,nr]= mm_tel_iau ## mm_total[ *,*,nr]

;SHORT WAY...
for nr=0, nrpos-1 do $
stk_corr[ *,*,nr]= mm_total[ *,*,nr] ## stk_meas[ *,*,nr] 


;stop

return
end
