pro rcvrfile_3C286_839MHz_22Jan2009, cfr, m_tot, m_astron, $
	deltag, epsilon, alpha, phi, chi, psi, angle_astron, $
	zero_deltag= zero_deltag

;+
; NAME:
;       rcvrfile_3C286_839MHz_22Jan2009
;
; PURPOSE: 
; Return M_TOT and M_ASTRON and other Mueller parameters for the 
;       RHSTK example file eg_pswitch.idl.pro
;
; CALLING SEQUENCE: 
;    rcvrfile_3C286_839MHz_22Jan2009, cfr, m_tot, m_astron, $
;	deltag, epsilon, alpha, phi, chi, psi, angle_astron, $
;	zero_deltag= zero_deltag
;
; IMPORTANT NOTE:
;       This file is a special case one because it uses derived 
;       parameters at a single frequency, AND READS THEM DIRECTLY from 
;       the file 
;               muellerparams_3C286_839MHz_22Jan2009.sav
; Normally, one determines
;       the frequency dependence and enters it by hand into the
;       rcvrfile. 
;       For a typical rcvrfile, see (for example) rcvr1_2__default.pro
;
; INPUT: 
;	CFR - frequency of observation.
;
; KEYWORD:
;       /ZERO_DELTAG: forces deltag in the mmatrix to zero, which should be
;                     set when you are using cal values adjusted make
;                     deltag zero.
;
; OUTPUT:
;       M_TOT: the feeds mueller matrix.
;
;       DELTAG, EPSILON, ALPHA, PHI, CHI, PSI: the parameters.  The units
;                                              of angles are radians.
; 
;       M_ASTRON: the matrix required to rotate the derived qsrc,usrc to
;                 astronomical pa.
;
;-

restore, 'muellerparams_3C286_839MHz_22Jan2009.sav'

deltag= muellerparams1.deltag
epsilon= muellerparams1.epsilon
alpha= muellerparams1.alpha
phi= muellerparams1.phi
chi= muellerparams1.chi
psi= muellerparams1.psi

m_tot, deltag, epsilon, alpha, phi, chi, psi, m_tot

;We are assuming that the position angle (PA) for 3C286 at 839 MHz is 31 deg.
;The MM determination for the system derives PA=24 deg.
pa= !dtor* 2.* (24.-31.)
m_astron = fltarr( 4,4)
m_astron[ 0,0] = 1.
m_astron[ 1,1] = cos( pa)
m_astron[ 2,1] = sin( pa)
m_astron[ 2,2] = cos( pa)
m_astron[ 1,2] = -sin( pa)
m_astron[ 3,3] = 1. 

end

