;STG1PRC.IDL.PRO creates the calibrated self- and cross-voltage products,
;       and the assoociated 'measured' Stokes parameters stki_meas, etc.

;GRAB THE CALON/OFF SPECTRA...  the prefix 'cal' means these are
;cal spectra, consisting of the noise diode on/off; cal spectra were
;done on source only.

;the suffix 10 means on source, off cal
;the suffix 11 means on source, on cal
indxcalon= where( cal[0].subscan[0].calstate eq 1, complement=indxcaloff)
calxx10= reform( (cal.subscan.spec)[ *,indxcaloff,0,*])
calxy10= reform( (cal.subscan.spec)[ *,indxcaloff,1,*])
calyy10= reform( (cal.subscan.spec)[ *,indxcaloff,2,*])
calyx10= reform( (cal.subscan.spec)[ *,indxcaloff,3,*])
calxx11= reform( (cal.subscan.spec)[ *,indxcalon,0,*])
calxy11= reform( (cal.subscan.spec)[ *,indxcalon,1,*])
calyy11= reform( (cal.subscan.spec)[ *,indxcalon,2,*])
calyx11= reform( (cal.subscan.spec)[ *,indxcalon,3,*])

tcalxx= cal[0].tcalxx
tcalyy= cal[0].tcalyy
; in init_cal, phase is in RADIANS and freq in MHZ
init_cal, gainchnls, tcalxx, tcalyy, freq_rf, dpdf_guess, $
              calxx11, calxx10, calyy11, calyy10, $
              calxy11, calxy10, calyx11, calyx10, $
              cts_per_k_xx, cts_per_k_yy, $
              phase_zero, phase_slope, phase_cntr, /rf

   caltime = cal.mjdstart

;NOW WE GRAB THE SRCON/OFF SPECTRA...
;WE FIND THE INDICES FOR WHICH WE ARE ONSRC OR OFFSRC WITH CAL OFF
;ndx00 is indices of off source, off cal
;ndx10 is indices of on source, off cal
;ndx01 is indices of off source, on cal
;ndx11 is indices of on source, on cal
;the cal is always off for these src data, so no ndx01, indx11

sz= size( src.subscan)

ndx00_src= where( strmatch( src.sname, '*off') eq 1, nrndx00_src)
ndx10_src= where( strmatch( src.sname, '*off') eq 0, nrndx10_src)

on= reform( src[ ndx10_src].subscan, sz[1]*nrndx10_src)
parallactic_on= parangle( 15.d0*on.lst- on.cra2000, on.cdec2000, src[0].antlat, /degree)
mjdrel_on= on.mjd- src[0].subscan[0].mjd

off= reform( src[ ndx00_src].subscan, sz[1]*nrndx00_src)
parallactic_off= parangle( 15.d0*off.lst- off.cra2000, off.cdec2000, src[0].antlat, /degree)
mjdrel_off= off.mjd- src[0].subscan[0].mjd

;DEFINE THE ON-SOURCE AND OFF-SOURCE PRODUCT SPECTRA...
nroff= n_elements( off)
nron= n_elements( on)
offoff= reform( off.spec)
onoff=  reform( on.spec)

xx00= reform( offoff[ *, 0, *])
xy00= reform( offoff[ *, 1, *])
yy00= reform( offoff[ *, 2, *])
yx00= reform( offoff[ *, 3, *])
xx10= reform( onoff[ *, 0, *])
xy10= reform( onoff[ *, 1, *])
yy10= reform( onoff[ *, 2, *])
yx10= reform( onoff[ *, 3, *])

;SELECT THE CAL INDEX FOR EACH SOURCE INDEX...
; We balanced, took a CALOFF/ON,
; Then we took 4 scans of ONSRC/OFFSRC/ONSRC/OFFSRC.
; So we go through all of the ON/OFF-SOURCE spectra and apply the
; PREVIOUS gain measurement...
; That is, we want to select the cal that was IMMEDIATELY PRIOR to the
; FIRST ON-SOURCE SUBSCAN time for a given scan.
ontime = on.mjd
cal_indx= lonarr( nron)
for nr= 0l, n_elements( caltime)- 1l do begin
      indx= where( caltime[nr] lt ontime, nrindx)
      if nrindx ne 0 then cal_indx[ indx]= nr
endfor

products_to_stokes_2021, gainchnls, cal_indx, $
        cts_per_k_xx, cts_per_k_yy, $
        phase_zero, phase_slope, freq_rf, $
        xx10, xx00, yy10, yy00, $
        xy10, xy00, yx10, yx00, $
        stki_meas, stkq_meas, stku_meas, stkv_meas, $
        xxcalib, yycalib, xycalib, yxcalib, $
        no_intensitycal=no_intensitycal, mean_med_off=mean_med_off


end


